"binom_two_singlestage"This class is created from the function freq_binom_two_singlestage. This is an intermediate stage to generate an object of class '>trialDesign_binom_two.
Objects can be created by calls of the form new("binom_two_singlestage", ...).
optimal:Object of class "data.frame", Optimal trial design
output:Object of class "data.frame", list of all acceptable trial designs
signature(x = "binom_two_singlestage")(x, t, r, pra, prb,
pta, ptb, futility_critical_value = 0.2,
efficacy_critical_value = 0.35, toxicity_critical_value = 0.3,
no_toxicity_critical_value = 0.1)
Class object which you wish to get properties for
A vector of the probability of response and toxicity for the simulation scenarios used to compute frequentist properties. The print function requires the first to be the alternative hypothesis and subsequent entries to be the three null hypotheses. This can be run with any scenario when not using the print method
A vector of the number of patients each interim and final analysis will occur at
Numeric values for the beta prior distribution to be used
Four values, for the critical values to be used as thresholds for the posterior distribution
# NOT RUN {
showClass("binom_two_singlestage")
# }
Run the code above in your browser using DataLab