freq_binom_one_landemets: Single arm, two stage, Binomial sample size calculator
Description
Sample size calculation for single arm, multistage trials using the alpha spending approach to reduce type I and type II error rates. This implimentation uses the O'Brien-Fleming alpha spending function for this purpose.