Get frequentist and Bayesian properties for a single-arm single binomial endpoint trial design.
properties_binom_one(failure = NULL, success = NULL, reviews = NULL,
p0, p1, prior.a = 0, prior.b = 0, round = TRUE, cutpoints = NULL)Vector of failures needed to stop the trial
Vector of successes needed to stop the trial
Vector of the number of patients at each analysis
probability of success under H0
probability of success under H1
beta prior parameters
Option whether to round results or not
Alternative usage, this replaces failure, success and reviews with a data.frame with columns of the same names