reviews:Object of class "numeric", numeric vector of the number of patients an interim analysis will occur at
success:Object of class "numeric", number of successed needed to stop for efficacy
failure:Object of class "numeric", number of failures needed to stop for futility
eta, zeta:Object of class "numeric", bayesiand properties of the design
alpha, power, exp.p0, exp.p1:Object of class "numeric", frequentist properties of the design including the expected sampel size under H0 and H1
p0, p1:Object of class "numeric", the probabilities used for H0 and H1 respectively