reviews:Object of class "numeric", a vector of the number of patients each interim analysis will occur at
data:Object of class "data.frame", exact simulation values for each scenario
cutpoints:Object of class "data.frame", the most extreme cutpoints when cause the trial to stop on their own (ignoring interaction with the other endpoint)
precision:Object of class "numeric", should be a vector of ones confirming probability is all accounted for
decision:Object of class "list", a list of matrices for the decisions to be made at each interim analysis
post.futility, post.efficacy, post.toxicity, post.no_toxicity:Object of class "numeric", The posterior probabilities of the design
graph:Object of class "list", an optional argument to pass to plot for the ploting of the first graph
- data
Exact simulation values for each scenario